@@ -1,12 +1,12 @@
-# -*- coding: utf-8 -*-
-import urllib
-import urlparse
-from django.conf.urls import patterns, url
+from copy import copy
+from urllib.parse import urlparse, urlunparse, urljoin, urlencode
+
+from django.urls import re_path
 from django.contrib.auth import login
 from django.contrib.auth.backends import ModelBackend
 from django.contrib.auth.models import User
-from django.core.urlresolvers import reverse
 from django.http import HttpResponseRedirect
+from django.urls import NoReverseMatch, reverse
 from django.views.generic import View
 from itsdangerous import URLSafeTimedSerializer
 from webservices.sync import SyncConsumer
@@ -18,13 +18,13 @@ class LoginView(View):
     def get(self, request):
         next = self.get_next()
         scheme = 'https' if request.is_secure() else 'http'
-        query = urllib.urlencode([('next', next)])
+        query = urlencode([('next', next)])
         netloc = request.get_host()
         path = reverse('simple-sso-authenticate')
-        redirect_to = urlparse.urlunparse((scheme, netloc, path, '', query, ''))
+        redirect_to = urlunparse((scheme, netloc, path, '', query, ''))
         request_token = self.client.get_request_token(redirect_to)
-        host = urlparse.urljoin(self.client.server_url, 'authorize/')
-        url = '%s?%s' % (host, urllib.urlencode([('token', request_token)]))
+        host = urljoin(self.client.server_url, 'authorize/')
+        url = '%s?%s' % (host, urlencode([('token', request_token)]))
         return HttpResponseRedirect(url)
 
     def get_next(self):
@@ -35,7 +35,7 @@ class LoginView(View):
         next = self.request.GET.get('next', None)
         if not next:
             return '/'
-        netloc = urlparse.urlparse(next)[1]
+        netloc = urlparse(next)[1]
         # Heavier security check -- don't allow redirection to a different
         # host.
         # Taken from django.contrib.auth.views.login
@@ -57,7 +57,7 @@ class AuthenticateView(LoginView):
         return HttpResponseRedirect(next)
 
 
-class Client(object):
+class Client:
     login_view = LoginView
     authenticate_view = AuthenticateView
     backend = "%s.%s" % (ModelBackend.__module__, ModelBackend.__name__)
@@ -74,29 +74,47 @@ class Client(object):
 
     @classmethod
     def from_dsn(cls, dsn):
-        parse_result = urlparse.urlparse(dsn)
+        parse_result = urlparse(dsn)
         public_key = parse_result.username
         private_key = parse_result.password
         netloc = parse_result.hostname
         if parse_result.port:
             netloc += ':%s' % parse_result.port
-        server_url = urlparse.urlunparse((parse_result.scheme, netloc, parse_result.path, parse_result.params, parse_result.query, parse_result.fragment))
+        server_url = urlunparse((parse_result.scheme, netloc, parse_result.path,
+                                 parse_result.params, parse_result.query, parse_result.fragment))
         return cls(server_url, public_key, private_key)
 
     def get_request_token(self, redirect_to):
-        return self.consumer.consume('/request-token/', {'redirect_to': redirect_to})['request_token']
+        try:
+            url = reverse('simple-sso-request-token')
+        except NoReverseMatch:
+            # thisisfine
+            url = '/request-token/'
+        return self.consumer.consume(url, {'redirect_to': redirect_to})['request_token']
 
     def get_user(self, access_token):
         data = {'access_token': access_token}
         if self.user_extra_data:
             data['extra_data'] = self.user_extra_data
-        user_data = self.consumer.consume('/verify/', data)
+
+        try:
+            url = reverse('simple-sso-verify')
+        except NoReverseMatch:
+            # thisisfine
+            url = '/verify/'
+        user_data = self.consumer.consume(url, data)
         user = self.build_user(user_data)
         return user
 
     def build_user(self, user_data):
         try:
             user = User.objects.get(username=user_data['username'])
+            # Update user data, excluding username changes
+            # Work on copied _tmp dict to keep an untouched user_data
+            user_data_tmp = copy(user_data)
+            del user_data_tmp['username']
+            for _attr, _val in user_data_tmp.items():
+                setattr(user, _attr, _val)
         except User.DoesNotExist:
             user = User(**user_data)
         user.set_unusable_password()
@@ -104,7 +122,7 @@ class Client(object):
         return user
 
     def get_urls(self):
-        return patterns('',
-            url(r'^$', self.login_view.as_view(client=self), name='simple-sso-login'),
-            url(r'^authenticate/$', self.authenticate_view.as_view(client=self), name='simple-sso-authenticate'),
-        )
+        return [
+            re_path(r'^$', self.login_view.as_view(client=self), name='simple-sso-login'),
+            re_path(r'^authenticate/$', self.authenticate_view.as_view(client=self), name='simple-sso-authenticate'),
+        ]
